@@ -2,4 +2,6 @@
 
 from .api import Schlage
 from .auth import Auth
-from .models import Lock
+from .lock import Lock
+
+__all__ = ("Auth", "Schlage", "Lock")
