@@ -183,7 +183,7 @@ class AccessCode(Mutable):
         return path
 
     @classmethod
-    def from_json(cls, auth: Auth, device: Device, json: dict[str, Any]) -> AccessCode:
+    def from_json(cls, auth: Auth, json: dict[str, Any], device: Device) -> AccessCode:
         """Creates an AccessCode from a JSON dict.
 
         :meta private:
@@ -202,13 +202,12 @@ class AccessCode(Mutable):
             access_code_id=json["accesscodeId"],
             name=json["friendlyName"],
             code=f"{json['accessCode']:0{access_code_length}}",
-            notify_on_use=bool(json["notification"]),
             disabled=bool(json.get("disabled", None)),
             schedule=schedule,
             device_id=device.device_id,
         )
 
-    def to_json(self) -> dict:
+    def to_json(self) -> dict[str, Any]:
         """Returns a JSON dict with this AccessCode's mutable properties.
 
         :meta private:
@@ -217,8 +216,7 @@ class AccessCode(Mutable):
             "friendlyName": self.name,
             "accessCode": int(self.code),
             "accessCodeLength": len(self.code),
-            "notification": int(self.notify_on_use),
-            "notificationEnabled": self.notify_on_use,
+            "notificationEnabled": int(self.notify_on_use),
             "disabled": int(self.disabled),
             "activationSecs": _MIN_TIME,
             "expirationSecs": _MAX_TIME,
