@@ -9,13 +9,13 @@ from dataclasses import dataclass, field
 class User:
     """A Schlage API user account."""
 
-    name: str = ""
+    name: str | None = None
     """The username associated with the account."""
 
     email: str = ""
     """The email associated with the account."""
 
-    user_id: str | None = field(default=None, repr=False)
+    user_id: str = field(default="", repr=False)
     """Unique identifier for the user."""
 
     @staticmethod
@@ -26,7 +26,7 @@ class User:
         """
         path = "users"
         if user_id:
-            return f"{path}/{user_id}"
+            return f"{path}/{user_id}"  # pragma: no cover
         return path
 
     @classmethod
@@ -36,7 +36,7 @@ class User:
         :meta private:
         """
         return User(
-            name=json["friendlyName"],
+            name=json.get("friendlyName"),
             email=json["email"],
             user_id=json["identityId"],
         )
