@@ -159,6 +159,28 @@ class TestLock:
         ]
         lock.refresh()
 
+        mock_auth.request.assert_has_calls([call("get", "devices/__wifi_uuid__")])
+        assert lock.name == "<NAME>"
+
+    def test_refresh_with_access_codes(
+        self,
+        mock_auth: Mock,
+        lock_json: dict[str, Any],
+        access_code_json: dict[str, Any],
+        notification_json: dict[str, Any],
+    ) -> None:
+        with pytest.raises(NotAuthenticatedError):
+            Lock().refresh()
+        lock = Lock.from_json(mock_auth, lock_json)
+        lock_json["name"] = "<NAME>"
+
+        mock_auth.request.side_effect = [
+            Mock(json=Mock(return_value=lock_json)),
+            Mock(json=Mock(return_value=[notification_json])),
+            Mock(json=Mock(return_value=[access_code_json])),
+        ]
+        lock.refresh(include_access_codes=True)
+
         mock_auth.request.assert_has_calls(
             [
                 call("get", "devices/__wifi_uuid__"),
@@ -296,56 +318,13 @@ class TestLock:
             ]
         )
         notification.device_type = lock.device_type
-        want_code = AccessCode.from_json(mock_auth, lock, access_code_json)
+        want_code = AccessCode.from_json(mock_auth, access_code_json, device=lock)
         want_code.device_id = lock.device_id
         want_code._notification = notification
         assert lock.access_codes == {
             access_code_json["accesscodeId"]: want_code,
         }
 
-    def test_add_access_code(
-        self,
-        mock_auth: Mock,
-        lock_json: dict[str, Any],
-        access_code_json: dict[str, Any],
-        notification_json: dict[str, Any],
-    ):
-        lock = Lock.from_json(mock_auth, lock_json)
-        code = AccessCode.from_json(mock_auth, lock, access_code_json)
-        # Users should not set these.
-        code._auth = None
-        code._device = None
-        code.access_code_id = None
-        code.device_id = None
-        json = code.to_json()
-
-        notification_json["active"] = False
-        mock_auth.request.side_effect = [
-            Mock(json=Mock(return_value=access_code_json)),
-            Mock(json=Mock(return_value=notification_json)),
-        ]
-        lock.add_access_code(code)
-
-        del notification_json["createdAt"]
-        del notification_json["updatedAt"]
-        mock_auth.request.assert_has_calls(
-            [
-                call(
-                    "post",
-                    "devices/__wifi_uuid__/commands",
-                    json={"data": json, "name": "addaccesscode"},
-                ),
-                call(
-                    "post",
-                    "notifications/<user-id>___access_code_uuid__",
-                    notification_json,
-                ),
-            ]
-        )
-        assert code._auth == mock_auth
-        assert code.device_id == lock.device_id
-        assert code.access_code_id == "__access_code_uuid__"
-
     def test_set_beeper(
         self, mock_auth: Mock, wifi_lock_json: dict[str, Any], wifi_lock: Lock
     ) -> None:
